#!/bin/bash

# Script to install/uninstall the ANN Toolbox 0.4.2 under Scilab 2.6

# Usage: To install:
#        -- check and edit the valiables below, as necessary
#
#        To uninstall:
#        -- call this script as 'install.sh uninstall'
#
# Notes: If ${SCIDIR} == ${INSTALL_DIR}, we assume
#        a system-wide install, on top of Scilab.

# Modify these variables as appropriate:
# --- top dir of scilab installation (e.g. where scilab.star resides)
SCIDIR='/usr/lib/scilab-2.6'
# --- installation directory (may be the same as above, for root install)
INSTALL_DIR="${HOME}/fileserver/tmp/ANN_Toolbox-0.4.2"
# INSTALL_DIR=${SCIDIR}

#--------------------------------------------------------------------
# you shouldn't need to change anything below

# 'true' if it's a system wide install
ROOT_INSTALL='false'
if [ "${INSTALL_DIR}" == "${SCIDIR}" ] ; then
	# we are installing on top of Scilab, be careful
	ROOT_INSTALL='true'
fi

# startup Scilab file
if [ "${ROOT_INSTALL}" == 'true' ] ; then
	# root install, edit the system wide startup
	SCILAB_STAR="${SCIDIR}/scilab.star"
else
	# local install, edit ~/.scilab
	SCILAB_STAR="${HOME}/.scilab"
fi

# make a backup, most likely we will modify this file
# (also needed by sed)
backup_star () {
	if [ -f ${SCILAB_STAR} ] ; then
		cp ${SCILAB_STAR} ${SCILAB_STAR}.old
		echo "Modified file: ${SCILAB_STAR}"
		echo "A backup copy have been saved with the extension .old"
	fi
}

# deal with the uninstall option first
if [ "$1" == "uninstall" ] ; then
	# remove our trash (partially)
	# we are careful not to do a recursive delete
	# in case ${INSTALL_DIR} have been left empty (being paranoid here)
	rm -R -f ${INSTALL_DIR}/examples/ann > /dev/null 2>&1
	rm -R -f ${INSTALL_DIR}/macros/ann   > /dev/null 2>&1
	rm -R -f ${INSTALL_DIR}/man/ann      > /dev/null 2>&1
	# remove the rest only if it wasn't a system-wide install
	# in case it was installed on top of Scilab
	# (I don't want recursive removal, just in case; being paranoid here)
	if [ "${ROOT_INSTALL}" == 'false' ] ; then
		rmdir ${INSTALL_DIR}/examples > /dev/null 2>&1
		rmdir ${INSTALL_DIR}/macros   > /dev/null 2>&1
		rmdir ${INSTALL_DIR}/man      > /dev/null 2>&1
		rmdir ${INSTALL_DIR}          > /dev/null 2>&1
	fi
	echo
	echo 'Uninstall done.'
	echo
	# now edit the ${SCILAB_STAR} file as required
	if grep -q -s "Artificial Neural Networks" ${SCILAB_STAR} ; then
		# we need to remove our trash
		# make a backup copy (also useful for sed)
		backup_star
		echo
		sed -e "\|^//---------- ANN Toolbox >>> DO NOT MODIFY THESE 4 LINES$| d" \
		    -e "\|^load('${INSTALL_DIR}/macros/ann/lib');$| d"                   \
		    -e "\|^%helps = \[%helps; \[\"${INSTALL_DIR}/man/ann\",\"Artificial Neural Networks\"\]\];$| d" \
		    -e "\|^//---------- ANN Toolbox >>> END$| d"                         \
			${SCILAB_STAR}.old > ${SCILAB_STAR}
	fi
	exit
fi

# create the directory structure:
mkdir -p ${INSTALL_DIR}/examples/ann
mkdir -p ${INSTALL_DIR}/macros/ann
mkdir -p ${INSTALL_DIR}/man/ann

# copy the examples files
cp -f -d examples/ann/* ${INSTALL_DIR}/examples/ann

# copy macro files, edit for local install and make
cp -f -d macros/ann/*.sci ${INSTALL_DIR}/macros/ann
sed -e "s|^SCIDIR=\.\./\.\.|SCIDIR=${SCIDIR}|"                               \
    -e "s|^NAM = SCI/macros/ann|NAM = ${INSTALL_DIR}/macros/ann|"            \
    -e "s|^include \.\./\.\./Makefile.incl|include ${SCIDIR}/Makefile.incl|" \
    -e "s|^include \.\./Make.lib|include ${SCIDIR}/macros/Make.lib|"         \
    macros/ann/Makefile.in > ${INSTALL_DIR}/macros/ann/Makefile
cd ${INSTALL_DIR}/macros/ann
make
cd ${OLDPWD}

# copy man files, edit for local install and make
cd man/ann
for man_page in `ls *.man` ; do
	 sed -e "s|^\.so \.\./sci\.an|\.so ${SCIDIR}/sci.an|" \
	     ${man_page} > ${INSTALL_DIR}/man/ann/${man_page}
done
cd ${INSTALL_DIR}/man
echo 'lines(0);formatman("ann","ascii");quit' | scilab -nw

# add ourselfs to the startup file as required and let the user know
if ! grep -q -s "Artificial Neural Networks" ${SCILAB_STAR} ; then
	# backup the old startup file
	echo
	backup_star
	echo
	echo '//---------- ANN Toolbox >>> DO NOT MODIFY THESE 4 LINES' >> ${SCILAB_STAR}
	echo -e "load(\047${INSTALL_DIR}/macros/ann/lib\047);"          >> ${SCILAB_STAR}
	echo -e "%helps = [%helps; \"${INSTALL_DIR}/man/ann\",\"Artificial Neural Networks\";];" >> ${SCILAB_STAR}
	echo '//---------- ANN Toolbox >>> END'                         >> ${SCILAB_STAR}
	echo "The ${SCILAB_STAR} file was updated to accomodate the ANN toolbox."
	echo
fi

